ProcessError class

Inheritance

Constructors

ProcessError(String? workingDirectory, String executable, List<String> arguments, ProcessResult result)

Properties

arguments → List<String>
final
executable → String
final
hashCode → int
The hash code for this object.
no setterinherited
result → ProcessResult
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited
workingDirectory → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited