ProtoBuilder class

Constructors

ProtoBuilder(BuilderOptions options)

Properties

buildExtensions → Map<String, List<String>>
Mapping from input file extension to output file extensions.
final
dartEnable ↔ bool
getter/setter pair
dartOutputDir ↔ String
getter/setter pair
downloadDepsFuture ↔ Future<void>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
javaEnable ↔ bool
getter/setter pair
javaOutputDir ↔ String
getter/setter pair
ocEnable ↔ bool
getter/setter pair
ocOutputDir ↔ String
getter/setter pair
protoc ↔ String?
getter/setter pair
protocGenDart ↔ String?
getter/setter pair
protocGenDartVersion ↔ String
getter/setter pair
protocGenGrpcJava ↔ String?
getter/setter pair
protocGenGrpcJavaVersion ↔ String
getter/setter pair
protocVersion ↔ String
getter/setter pair
protoDir ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) → Future<void>
Generates the outputs for a given BuildStep.
downloadDeps() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited