StringResBuilder class

Constructors

StringResBuilder(BuilderOptions options)

Properties

buildExtensions → Map<String, List<String>>
Mapping from input file extension to output file extensions.
final
defaultLang ↔ String
The default language
latefinal
genCodeDir ↔ String
The directory for generated code
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onlyGenKey ↔ bool
If set true, only the keys of the string resources will be generated.
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringResFileName → String
final
stringResKeyFileName → String
The generated code file name for string res keys.
final
stringResPathMap ↔ Map<String, String>?
The strings resource paths for multi-language. The key is country code, the value is strings resource path.
getter/setter pair

Methods

build(BuildStep buildStep) → Future<void>
Generates the outputs for a given BuildStep.
generateStringRes(BuildStep buildStep) → Future<void>
generateStringResKey(BuildStep buildStep) → Future<void>
getSupportLanguage() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited